#
# spec file for package sord
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           sord
Version:        0.16.16
Release:        1.1
Summary:        Utilities to work with RDF data
License:        ISC
Group:          Productivity/File utilities
URL:            https://drobilla.net/software/sord.html
Source0:        https://download.drobilla.net/sord-%{version}.tar.xz
Source1:        https://download.drobilla.net/sord-%{version}.tar.xz.sig
Source2:        sord.keyring
Source3:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  meson
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  pkgconfig(serd-0) >= 0.30.10
BuildRequires:  pkgconfig(zix-0) >= 0.4.0

%description
Utilities to work with RDF data.
Sord is a lightweight C library for storing RDF data in memory.

%package        -n libsord-0-%{sover}
Summary:        A lightweight C library for storing RDF data in memory
Group:          System/Libraries

%description    -n libsord-0-%{sover}
A lightweight C library for storing RDF data in memory.
http://drobilla.net/software/sord/

%package        devel
Summary:        Development files for libsord
Group:          Development/Libraries/C and C++
Requires:       libsord-0-%{sover} = %{version}
Provides:       libsord-0-devel = %{version}
Obsoletes:      libsord-0-devel < %{version}

%description    devel
Development files for libsord.
Sord is a lightweight C library for storing RDF data in memory.

%prep
%autosetup -p1

%build
%meson -Ddocs=enabled -Dtests=enabled
%meson_build

%install
%meson_install
rm -rf %{buildroot}%{_datadir}/doc/sord-0/html

%check
%meson_test

%post -n libsord-0-%{sover} -p /sbin/ldconfig
%postun -n libsord-0-%{sover} -p /sbin/ldconfig

%files
%attr(0755,root,root) %{_bindir}/sordi
%attr(0755,root,root) %{_bindir}/sord_validate
%{_mandir}/man1/sordi.1%{?ext_man}
%{_mandir}/man1/sord_validate.1%{?ext_man}

%files -n libsord-0-%{sover}
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/libsord-0.so.%{sover}*

%files devel
%{_libdir}/libsord-0.so
%{_includedir}/sord-0/
%{_libdir}/pkgconfig/sord-0.pc

%changelog
* Sun Jan 19 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- remove 67bcd63bda9d7b095489a09b9880aa730ddb5488.patch now upstream
- update to 0.16.16
  * Allow SORD_API to be defined by the user
  * Fix command line help interface of sord_validate
  * Fix dependencies in pkg-config file
  * Override pkg-config dependency within meson
  * Port sord_validate to pcre2
  * Switch to external zix dependency
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sun Sep 10 2023 Luigi Baldoni <aloisio@gmx.com>
- Update version for buildtime requirement
* Fri Oct 14 2022 Stephan Kulow <coolo@suse.com>
- Adding 67bcd63bda9d7b095489a09b9880aa730ddb5488.patch from upstrea
  commit to suport pcre2 in favor of pcre1
* Fri Oct 14 2022 Stephan Kulow <coolo@suse.com>
- update to 0.16.14:
  * Adopt REUSE machine-readable licensing standard
  * Allow programs to be used from subproject
  * Fix accidentally exposed internal zix symbols
  * Fix various warnings
  * Switch to meson build system
* Tue Aug  9 2022 Dirk Müller <dmueller@suse.com>
- add gpg validation of release
* Mon Jun 27 2022 Dirk Müller <dmueller@suse.com>
- update to 0.16.10:
  * Fix Windows build
  * Fix potential crash or incorrectness issue with GCC 10 again
* Tue Jan 19 2021 Dirk Müller <dmueller@suse.com>
- update to 0.16.8:
  * Clean up code
  * Fix potential undefined behavior
  * Fix potentially incorrect search results
  * Remove the need for a generated configuration header
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 0.16.6:
  * Fix potential crash or incorrectness issues with GCC 10
  * Fix various minor warnings and other code quality issues
* Fri Apr 17 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.16.4:
  * Update build system
* Fri Aug 24 2018 tchvatal@suse.com
- Update to 0.16.2:
  * Update waf bundle to 2.0.9
  * Fix warious compiler warnings and clang-format reports
* Thu Nov  2 2017 mpluskal@suse.com
- Update to version 0.16.0:
  * Fix construction and comparison of URIs with UTF-8 characters
  * Fix documentation generation
  * Return error from sord_inserter_write_statement() if a node can
    not be written (e.g. undefined prefix)
  * Make sord_node_get_counted return byte count, and clarify
    documentation
  * Safely return NULL from sord_iter_get() for end iterators
  * Add sord_node_get_string_measured() to get both byte and
    character counts
  * sord_validate: Do proper numeric comparison for propery bounds
    checking
  * sord_validate: Tolerate xsd:decimal literals for double and
    float properties if literals match pattern
- Use python3
- Rename devel subpackage
- Run tests during building
* Mon Jan 30 2017 jengelh@inai.de
- Rename soname macro to sover as it does not contain a name
* Thu Jan 12 2017 olaf@aepfle.de
- Add baselibs.conf for gstreamer-plugins-bad-32bit
* Thu Dec 17 2015 davejplater@gmail.com
- Added manpage sord.3 and api docs to devel package.
* Wed Dec 16 2015 olaf@aepfle.de
- Add BuildRoot: for SLE_11
* Wed Dec  9 2015 someuniquename@gmail.com
- Removed doc package due to build problems.
- Update to version 0.14.0 stable;
  * Reduce memory usage and increase performance with a better data structure
  * Add sord_erase() for erasing statements via an iterator
  * Fix bugs with stores that contain both graphs and default graph statements
  * Fix crash caused by multiple deletion of datatype nodes
  * Fix compilation on compilers that do not support -pthread flag
  * Fix minor memory leak in sordi
  * Fix using sordi with stdin
  * Show sordi errors in standard format
  * sord_validate: More extensive validation, including cardinality,
    PlainLiteral, and someValuesFrom restrictions.
  * This release does not break the ABI, but the semantics of iterators has
    changed: any modification to a model invalidates iterators on that model
  * Improve test coverage
  * Upgrade to waf 1.8.14
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 0.12.2
  * Fix iteration over an entire graph (* * * graph)
  * sordmm.hpp: Remove unused members
  * Update to waf 1.7.16
* Thu Sep  5 2013 reddwarf@opensuse.org
- Update to 0.12.0
  * Update to waf 1.7.9 and autowaf r90 (install docs to versioned directory)
  * Add sord_get() for easily getting single property values
  * sord_validate: Pass type check when range is xsd:anyURI and value is a URI
  * sord_validate: Support any subClassOf rdf:Property, not just baked-in ones
  * sordmm.hpp: Add convenient constructors for decimal and integer literals
  * sordmm.hpp: Add Node::to_serd_node()
  * sordmm.hpp: Don't automatically add RDF namespace prefix to world
* Tue Oct 23 2012 reddwarf@opensuse.org
- Remove sord-0.8.0-no_g++.patch, applied upstream
- Update to 0.10.4
  * Implement better data type validation in sord_validate conformant with
    the XSD and OWL specifications
  * Fix memory leaks in sord_validate
  * Install sord_validate man page
  * Disable timestamps in HTML documentation for reproducible build
  * Add error callback to world for custom error reporting
  * Performance and space (per node) improvements
  * SSE4.2 accelerated hashing for node interning, where available
  * Make all 'zix' symbols private to avoid symbol clashes in static builds
  * Remove problematic "Loaded n statements" output from serdi
  * Strip down API documentation to a single clean page
  * Fix various hyper-strict warnings
  * Do not require a C++ compiler to build
  * Add option to build utilities as static binaries
  * Upgrade to waf 1.7.2
  * sordmm.hpp: Add indices and graphs parameters to Model constructor
  * sordmm.hpp: Remove overzealous URI scheme assertion
  * sordmm.hpp: Correctly handle Sord::Node self-assignment
* Thu Aug 16 2012 reddwarf@opensuse.org
- Fix main package metadata
- Install sord_validate man page
- Created a libsord-docs subpackage to let multiple devel packages
  with different APIs to be installed at the same time
* Wed Aug  8 2012 reddwarf@opensuse.org
- First version of the package
- Added sord-0.8.0-no_g++.patch
